[OE-core] [PATCH 21/22] midori: remove the recipe and replace references to midori with epiphany

2015-08-19 Thread Alexander Kanavin
Signed-off-by: Alexander Kanavin alexander.kana...@linux.intel.com
---
 .../packagegroups/packagegroup-self-hosted.bb  |  7 +
 .../builder/files/builder_hob_start.sh |  8 +++---
 meta/recipes-sato/midori/midori/liststore.patch| 29 
 meta/recipes-sato/midori/midori_0.5.8.bb   | 31 --
 .../packagegroups/packagegroup-core-x11-sato.bb|  2 +-
 5 files changed, 6 insertions(+), 71 deletions(-)
 delete mode 100644 meta/recipes-sato/midori/midori/liststore.patch
 delete mode 100644 meta/recipes-sato/midori/midori_0.5.8.bb

diff --git a/meta/recipes-core/packagegroups/packagegroup-self-hosted.bb 
b/meta/recipes-core/packagegroups/packagegroup-self-hosted.bb
index 7d5a41a..d38be26 100644
--- a/meta/recipes-core/packagegroups/packagegroup-self-hosted.bb
+++ b/meta/recipes-core/packagegroups/packagegroup-self-hosted.bb
@@ -28,11 +28,6 @@ RDEPENDS_packagegroup-self-hosted = \
 packagegroup-self-hosted-host-tools \
 
 
-# midori depends on webkit-gtk which could not build for mips64
-MIDORI = midori
-MIDORI_mips64 = 
-MIDORI_mips64n32 = 
-
 RDEPENDS_packagegroup-self-hosted-host-tools = \
 connman \
 connman-plugin-ethernet \
@@ -198,7 +193,7 @@ RDEPENDS_packagegroup-self-hosted-graphics = \
 python-pygtk \
 gtk-theme-clearlooks \
 xdg-utils \
-${MIDORI} \
+epiphany \
 leafpad \
 pcmanfm \
 vte \
diff --git a/meta/recipes-sato/midori/midori/liststore.patch 
b/meta/recipes-sato/midori/midori/liststore.patch
deleted file mode 100644
index 4e5d666..000
--- a/meta/recipes-sato/midori/midori/liststore.patch
+++ /dev/null
@@ -1,29 +0,0 @@
-GLib 2.44 has a GListStore type which is GLib.ListStore in Vala, resulting in 
an ambigous type and compile failure.
-
-Fix by using the full type name.
-
-Upstream-Status: Backport
-Signed-off-by: Ross Burton ross.bur...@intel.com
-
-diff --git a/extensions/history-list.vala b/extensions/history-list.vala
-index 3a864b1..f309c0c 100644
 a/extensions/history-list.vala
-+++ b/extensions/history-list.vala
-@@ -319,7 +319,7 @@ namespace HistoryList {
- }
- 
- private void create_widgets () {
--ListStore model;
-+Gtk.ListStore model;
- TreeIter iter;
- TreeIter? active_iter = null;
- 
-@@ -331,7 +331,7 @@ namespace HistoryList {
- 
- var tab_closing_behavior = this.hl_manager.get_integer 
(TabClosingBehavior);
- 
--model = new ListStore (2, typeof (string), typeof (int));
-+model = new Gtk.ListStore (2, typeof (string), typeof (int));
- 
- model.append (out iter);
- model.set (iter, TabClosingBehaviorModel.TEXT, _(Do nothing),
diff --git a/meta/recipes-sato/midori/midori_0.5.8.bb 
b/meta/recipes-sato/midori/midori_0.5.8.bb
deleted file mode 100644
index 1c027fe4..000
--- a/meta/recipes-sato/midori/midori_0.5.8.bb
+++ /dev/null
@@ -1,31 +0,0 @@
-SUMMARY = A lightweight web browser
-HOMEPAGE = http://midori-browser.org/;
-LICENSE = LGPLv2.1
-LIC_FILES_CHKSUM = file://COPYING;md5=fbc093901857fcd118f065f900982c24
-DEPENDS = webkit-gtk libsoup-2.4 openssl python-native python-docutils-native 
librsvg-native libnotify libxscrnsaver
-
-SRC_URI = 
https://launchpad.net/midori/trunk/0.5.8/+download/${BPN}-${PV}.tar.bz2;subdir=${BPN}-${PV}
 \
-   file://liststore.patch
-
-SRC_URI[md5sum] = b89e25e74199d705e74767499a415976
-SRC_URI[sha256sum] = 
af19135fd4c4b04345df4d3592e7939c20f9b40eaca24550e6cb619751aa9381
-
-# midori depends on webkit-gtk, and webkit-gtk can NOT be built on
-# MIPS64 with n32 ABI. So remove it from mips64 n32 temporarily.
-COMPATIBLE_HOST_mips64n32 = null
-
-inherit gtk-icon-cache pkgconfig vala pythonnative cmake distro_features_check
-
-# The webkit-gtk and libxscrnsaver requires x11 in DISTRO_FEATURES
-REQUIRED_DISTRO_FEATURES = x11
-
-EXTRA_OECMAKE =  \
--DCMAKE_INSTALL_PREFIX=${prefix} \
--DUSE_ZEITGEIST=0 \
-
-

Re: [OE-core] [PATCH 21/22] midori: remove the recipe and replace references to midori with epiphany

2015-08-17 Thread Alexander Kanavin

On 08/15/2015 07:59 AM, Randy MacLeod wrote:


-# midori depends on webkit-gtk which could not build for mips64
-MIDORI = midori
-MIDORI_mips64 = 
-MIDORI_mips64n32 = 
+# epiphany depends on webkitgtk which could not build for mips64
+EPIPHANY = epiphany
+EPIPHANY_mips64 = 
+EPIPHANY_mips64n32 = 


Mips64 support using the newer webkitgtk may be better.
Wenzong please check on that once this code is in master-next
and reply here.


Latest Webkit (2.8.5) actually does build for MIPS64 (where 2.8.4 
failed), but I couldn't find a way to test the n32 variant using poky - 
any suggestions?


I'll drop the above lines for now.


Alex
--
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 21/22] midori: remove the recipe and replace references to midori with epiphany

2015-08-17 Thread Alexander Kanavin

On 08/17/2015 06:48 PM, Khem Raj wrote:


Mips64 support using the newer webkitgtk may be better.
Wenzong please check on that once this code is in master-next
and reply here.


Latest Webkit (2.8.5) actually does build for MIPS64 (where 2.8.4 failed), but 
I couldn't find a way to test the n32 variant using poky - any suggestions?



may be you can use multilib on same mips64 configuration and build 
libn32-epiphany ?


Thanks, I'll also try to see if powerpc64 build can be tested the same 
way, because it was not, for the same reason (poky has a configuration 
for ppc, but not ppc64).



Alex
--
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 21/22] midori: remove the recipe and replace references to midori with epiphany

2015-08-17 Thread Randy MacLeod

On 2015-08-17 12:04 PM, Alexander Kanavin wrote:

On 08/17/2015 06:48 PM, Khem Raj wrote:


Mips64 support using the newer webkitgtk may be better.
Wenzong please check on that once this code is in master-next
and reply here.


Latest Webkit (2.8.5) actually does build for MIPS64 (where 2.8.4
failed), but I couldn't find a way to test the n32 variant using poky
- any suggestions?



may be you can use multilib on same mips64 configuration and build
libn32-epiphany ?


Thanks, I'll also try to see if powerpc64 build can be tested the same
way, because it was not, for the same reason (poky has a configuration
for ppc, but not ppc64).


It would be nice to add qemuppc64 but it's not a high priority.
Interested? :)
../Randy




Alex



--
# Randy MacLeod. SMTS, Linux, Wind River
Direct: 613.963.1350 | 350 Terry Fox Drive, Suite 200, Ottawa, ON, 
Canada, K2K 2W5

--
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 21/22] midori: remove the recipe and replace references to midori with epiphany

2015-08-17 Thread Khem Raj

 On Aug 17, 2015, at 5:56 AM, Alexander Kanavin 
 alexander.kana...@linux.intel.com wrote:
 
 On 08/15/2015 07:59 AM, Randy MacLeod wrote:
 
 -# midori depends on webkit-gtk which could not build for mips64
 -MIDORI = midori
 -MIDORI_mips64 = 
 -MIDORI_mips64n32 = 
 +# epiphany depends on webkitgtk which could not build for mips64
 +EPIPHANY = epiphany
 +EPIPHANY_mips64 = 
 +EPIPHANY_mips64n32 = 
 
 Mips64 support using the newer webkitgtk may be better.
 Wenzong please check on that once this code is in master-next
 and reply here.
 
 Latest Webkit (2.8.5) actually does build for MIPS64 (where 2.8.4 failed), 
 but I couldn't find a way to test the n32 variant using poky - any 
 suggestions?


may be you can use multilib on same mips64 configuration and build 
libn32-epiphany ?

 
 I'll drop the above lines for now.
 
 
 Alex
 --
 ___
 Openembedded-core mailing list
 Openembedded-core@lists.openembedded.org
 http://lists.openembedded.org/mailman/listinfo/openembedded-core



signature.asc
Description: Message signed with OpenPGP using GPGMail
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 21/22] midori: remove the recipe and replace references to midori with epiphany

2015-08-14 Thread Randy MacLeod

On 2015-08-14 06:55 AM, Alexander Kanavin wrote:

-# midori depends on webkit-gtk which could not build for mips64
-MIDORI = midori
-MIDORI_mips64 = 
-MIDORI_mips64n32 = 
+# epiphany depends on webkitgtk which could not build for mips64
+EPIPHANY = epiphany
+EPIPHANY_mips64 = 
+EPIPHANY_mips64n32 = 


Mips64 support using the newer webkitgtk may be better.
Wenzong please check on that once this code is in master-next
and reply here.

Thanks,

--
# Randy MacLeod. SMTS, Linux, Wind River
Direct: 613.963.1350 | 350 Terry Fox Drive, Suite 200, Ottawa, ON, 
Canada, K2K 2W5

--
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 21/22] midori: remove the recipe and replace references to midori with epiphany

2015-08-14 Thread Alexander Kanavin
Signed-off-by: Alexander Kanavin alexander.kana...@linux.intel.com
---
 .../packagegroups/packagegroup-self-hosted.bb  | 10 +++
 .../builder/files/builder_hob_start.sh |  8 +++---
 meta/recipes-sato/midori/midori/liststore.patch| 29 
 meta/recipes-sato/midori/midori_0.5.8.bb   | 31 --
 .../packagegroups/packagegroup-core-x11-sato.bb|  2 +-
 5 files changed, 10 insertions(+), 70 deletions(-)
 delete mode 100644 meta/recipes-sato/midori/midori/liststore.patch
 delete mode 100644 meta/recipes-sato/midori/midori_0.5.8.bb

diff --git a/meta/recipes-core/packagegroups/packagegroup-self-hosted.bb 
b/meta/recipes-core/packagegroups/packagegroup-self-hosted.bb
index 7d5a41a..0c79827 100644
--- a/meta/recipes-core/packagegroups/packagegroup-self-hosted.bb
+++ b/meta/recipes-core/packagegroups/packagegroup-self-hosted.bb
@@ -28,10 +28,10 @@ RDEPENDS_packagegroup-self-hosted = \
 packagegroup-self-hosted-host-tools \
 
 
-# midori depends on webkit-gtk which could not build for mips64
-MIDORI = midori
-MIDORI_mips64 = 
-MIDORI_mips64n32 = 
+# epiphany depends on webkitgtk which could not build for mips64
+EPIPHANY = epiphany
+EPIPHANY_mips64 = 
+EPIPHANY_mips64n32 = 
 
 RDEPENDS_packagegroup-self-hosted-host-tools = \
 connman \
@@ -198,7 +198,7 @@ RDEPENDS_packagegroup-self-hosted-graphics = \
 python-pygtk \
 gtk-theme-clearlooks \
 xdg-utils \
-${MIDORI} \
+${EPIPHANY} \
 leafpad \
 pcmanfm \
 vte \
diff --git a/meta/recipes-sato/midori/midori/liststore.patch 
b/meta/recipes-sato/midori/midori/liststore.patch
deleted file mode 100644
index 4e5d666..000
--- a/meta/recipes-sato/midori/midori/liststore.patch
+++ /dev/null
@@ -1,29 +0,0 @@
-GLib 2.44 has a GListStore type which is GLib.ListStore in Vala, resulting in 
an ambigous type and compile failure.
-
-Fix by using the full type name.
-
-Upstream-Status: Backport
-Signed-off-by: Ross Burton ross.bur...@intel.com
-
-diff --git a/extensions/history-list.vala b/extensions/history-list.vala
-index 3a864b1..f309c0c 100644
 a/extensions/history-list.vala
-+++ b/extensions/history-list.vala
-@@ -319,7 +319,7 @@ namespace HistoryList {
- }
- 
- private void create_widgets () {
--ListStore model;
-+Gtk.ListStore model;
- TreeIter iter;
- TreeIter? active_iter = null;
- 
-@@ -331,7 +331,7 @@ namespace HistoryList {
- 
- var tab_closing_behavior = this.hl_manager.get_integer 
(TabClosingBehavior);
- 
--model = new ListStore (2, typeof (string), typeof (int));
-+model = new Gtk.ListStore (2, typeof (string), typeof (int));
- 
- model.append (out iter);
- model.set (iter, TabClosingBehaviorModel.TEXT, _(Do nothing),
diff --git a/meta/recipes-sato/midori/midori_0.5.8.bb 
b/meta/recipes-sato/midori/midori_0.5.8.bb
deleted file mode 100644
index 1c027fe4..000
--- a/meta/recipes-sato/midori/midori_0.5.8.bb
+++ /dev/null
@@ -1,31 +0,0 @@
-SUMMARY = A lightweight web browser
-HOMEPAGE = http://midori-browser.org/;
-LICENSE = LGPLv2.1
-LIC_FILES_CHKSUM = file://COPYING;md5=fbc093901857fcd118f065f900982c24
-DEPENDS = webkit-gtk libsoup-2.4 openssl python-native python-docutils-native 
librsvg-native libnotify libxscrnsaver
-
-SRC_URI = 
https://launchpad.net/midori/trunk/0.5.8/+download/${BPN}-${PV}.tar.bz2;subdir=${BPN}-${PV}
 \
-   file://liststore.patch
-
-SRC_URI[md5sum] = b89e25e74199d705e74767499a415976
-SRC_URI[sha256sum] = 
af19135fd4c4b04345df4d3592e7939c20f9b40eaca24550e6cb619751aa9381
-
-# midori depends on webkit-gtk, and webkit-gtk can NOT be built on
-# MIPS64 with n32 ABI. So remove it from mips64 n32 temporarily.
-COMPATIBLE_HOST_mips64n32 = null
-
-inherit gtk-icon-cache pkgconfig vala pythonnative cmake distro_features_check
-
-# The webkit-gtk and libxscrnsaver requires x11 in DISTRO_FEATURES
diff --git a/meta/recipes-graphics/builder/files/builder_hob_start.sh 
b/meta/recipes-graphics/builder/files/builder_hob_start.sh
index 65a68ee..b394b09 100644
--- a/meta/recipes-graphics/builder/files/builder_hob_start.sh
+++ b/meta/recipes-graphics/builder/files/builder_hob_start.sh
@@ -18,10 +18,10 @@ if [ ! -d /home/builder/.local/share/applications ]; then
 #register folders to open with PCManFM filemanager
 xdg-mime default pcmanfm.desktop inode/directory
 
-#register html links and files with Midori
-xdg-mime default midori.desktop x-scheme-handler/http
-xdg-mime default midori.desktop x-scheme-handler/https
-xdg-mime default midori.desktop text/html
+#register html links and files with epiphany
+xdg-mime default epiphany.desktop x-scheme-handler/http
+xdg-mime default epiphany.desktop x-scheme-handler/https
+xdg-mime default epiphany.desktop text/html
 
 #register text files with leafpad text editor
 xdg-mime default leafpad.desktop text/plain
diff --git a/meta/recipes-graphics/builder/files/builder_hob_start.sh 
b/meta/recipes-graphics/builder/files/builder_hob_start.sh
index 65a68ee..b394b09 100644
--- a/meta/recipes-graphics/builder/files/builder_hob_start.sh
+++ b/meta/recipes-graphics/builder/files/builder_hob_start.sh
@@ -18,10 +18,10 @@ if [ ! -d /home/builder/.local/share/applications ]; then
 #register folders to open with PCManFM filemanager
 xdg-mime default pcmanfm.desktop inode/directory
 
-#register html links and files with Midori
-xdg-mime default midori.desktop x-scheme-handler/http
-xdg-mime default midori.desktop x-scheme-handler/https
-xdg-mime default midori.desktop text/html
+#register html links and files with epiphany
+xdg-mime default epiphany.desktop x-scheme-handler/http
+xdg-mime default epiphany.desktop x-scheme-handler/https
+xdg-mime default epiphany.desktop text/html
 
 #register text files with leafpad text editor
 xdg-mime default leafpad.desktop text/plain